searchData={"items":[{"type":"module","title":"Exinertia","doc":"Documentation for `Exinertia`.","ref":"Exinertia.html"},{"type":"task","title":"mix exinertia.install","doc":"Installs Exinertia and updates your project accordingly.\n\nThis installer automates the basic steps for integrating Exinertia into a Phoenix project\nusing bun for JavaScript and CSS bundling, removing esbuild/tailwind configs, and adding\na simple Inertia setup.\n\nIt follows the rough steps:\n\n  1. Create a Vite manifest reader in your Web app folder.\n  2. Add Inertia and bun to your mix.exs, remove esbuild/tailwind if present, and run deps.get.\n  3. Update config.exs to configure bun.\n  4. Update dev.exs watchers to point to bun and remove esbuild/tailwind watchers.\n  5. Modify your router and add an :inertia pipeline + a test route.\n  6. Modify a controller to render an Inertia page.\n  7. Create an inertia_root.html.heex layout.\n  8. Modify the existing root.html.heex to reference your new Vite manifest for main.js.\n  9. Insert Inertia imports into lib/myapp_web.ex for your controllers/templates.\n  10. Update mix aliases for building/deploying assets with bun.","ref":"Mix.Tasks.Exinertia.Install.html"},{"type":"task","title":"Example - mix exinertia.install","doc":"```bash\nmix exinertia.install\n```","ref":"Mix.Tasks.Exinertia.Install.html#module-example"},{"type":"task","title":"mix exinertia.setup","doc":"Creates a new frontend for Inertia.js.\n\nThis task clones the Inertia.js template and then installs its dependencies.\nAs a final note, ensure your tailwind.config.js is updated with the proper content paths.","ref":"Mix.Tasks.Exinertia.Setup.html"},{"type":"extras","title":"ExInertia","doc":"# ExInertia\n\nExInertia is a toolkit for seamlessly integrating Inertia.js with Phoenix, using Bun for JavaScript and CSS bundling.","ref":"readme.html"},{"type":"extras","title":"Installation - ExInertia","doc":"Add ExInertia to your dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:exinertia, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - ExInertia","doc":"ExInertia provides two main mix tasks to get you up and running:\n\n1. Install ExInertia and configure your project:\n```bash\nmix exinertia.install\n```\n\n2. Install dependencies and Bun:\n```bash\nmix deps.get\nmix bun.install\n```\n\n3. Scaffold the Inertia frontend:\n```bash\nmix exinertia.setup\n```","ref":"readme.html#quick-start"},{"type":"extras","title":"What does `exinertia.install` do? - ExInertia","doc":"The installer automates the basic steps for integrating ExInertia into a Phoenix project:\n\n1. Creates a Vite manifest reader in your Web app folder\n2. Adds Inertia and Bun to your mix.exs\n3. Updates config.exs to configure Bun\n4. Updates dev.exs watchers to point to Bun\n5. Modifies your router and adds an :inertia pipeline + test route\n6. Modifies a controller to render an Inertia page\n7. Creates an inertia_root.html.heex layout\n8. Modifies the existing root.html.heex to reference your Vite manifest\n9. Inserts Inertia imports into lib/myapp_web.ex\n10. Updates mix aliases for building/deploying assets with Bun","ref":"readme.html#what-does-exinertia-install-do"},{"type":"extras","title":"What does `exinertia.setup` do? - ExInertia","doc":"The setup task:\n\n1. Clones a React TypeScript template for Inertia.js\n2. Sets up the frontend assets in your `assets` directory\n3. Installs all necessary frontend dependencies using Bun","ref":"readme.html#what-does-exinertia-setup-do"},{"type":"extras","title":"After Installation - ExInertia","doc":"After running both commands, you'll need to:\n\n1. Run `mix deps.get` to install new dependencies\n2. Run `mix bun.install` to install Bun and dependencies\n3. Update your `tailwind.config.js` to include `\"./js/**/*.{js,ts,jsx,tsx}\"` in the content paths","ref":"readme.html#after-installation"},{"type":"extras","title":"Development - ExInertia","doc":"Start your Phoenix server:\n\n```bash\nmix phx.server\n```\n\nVisit [`localhost:4000/inertia`](http://localhost:4000/inertia) to see your Inertia-powered page.","ref":"readme.html#development"},{"type":"extras","title":"Learn More - ExInertia","doc":"- [Inertia.js Documentation](https://inertiajs.com/)\n- [Phoenix Framework Documentation](https://hexdocs.pm/phoenix/overview.html)\n- [Bun Documentation](https://bun.sh/docs)","ref":"readme.html#learn-more"},{"type":"extras","title":"License - ExInertia","doc":"ExInertia is released under the MIT License.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}